# Abut.tcl - takes gap and generates abutment materials
# Units: k, in
# Kevin Mackie, 2002/01/29
# mackie@ce.berkeley.edu
#
# Takes quantities from GenerateBridge.tcl and generates materials for
# use in abutment array.  Values input for stiffnesses in each direction.
# input  - gapl abutment gap longitudinal (in)
#        - gapt abutment gap transverse (in)

proc Abut {gapl gapt kl kt kv} {

      # abutment backwall (longitudinal)
      uniaxialMaterial ElasticPPGap  32   $kl   -$kl   -$gapl
      uniaxialMaterial Parallel      42   32  -min [expr -$gapl-7.0] -max [expr $gapl+7.0]
      # vertical
      uniaxialMaterial Elastic       43   $kv
      # radial (transverse)
      if { $gapt == 100 } {
         uniaxialMaterial ElasticPPGap  34   [expr $kt/1e6]  [expr -$kt/1e3]   -0.0
         uniaxialMaterial ElasticPPGap  35   [expr $kt/1e6]  [expr  $kt/1e3]    0.0
         uniaxialMaterial Parallel      44   34 35 -min -7.0 -max 7.0
      } else {
         uniaxialMaterial ElasticPPGap  34    $kt    -$kt    -0.0
         uniaxialMaterial ElasticPPGap  35    $kt     $kt     0.0
         uniaxialMaterial Parallel      44   34 35 -min -7.0 -max 7.0
      }

}