# PYspring.tcl - takes NL p-y soil spring backbone and returns stiffness
# Units: lb, in
# Kevin Mackie, 2000/07/13
# mackie@ce.berkeley.edu
#
# Takes quantities from GenerateBridge.tcl and generates nonlinear p-y curve
# for given soil and depth, then calculates the stiffness and yield values
# input  - pu ultimate resistance (lb/in)
#        - kp initial modulus of subgrade reaction (lb/in^3)
# output - kpy stiffness (k/in)
#        - epy yield displacement (in)

proc PYspring {pu kp cur_depth trib mat_num} {

# UP is a spring strength modification factor
set UP 1.00
set pr_y 0.0
set pr_p 0.0
set pr_tan 100.0
set yval 0.01
set incr 0.01

while { $pr_tan > 50.0 } {
   set Pval [expr $UP*$trib*0.9*$pu*tanh($kp*$cur_depth/0.9/$pu*$yval)]
   set pr_tan [expr ($Pval-$pr_p)/($yval-$pr_y)]
   set pr_y $yval
   set pr_p $Pval
   set yval [expr $yval+$incr]
}
set Pmax $Pval
set cr_pl [expr 0.75*$Pmax]

set pr_y 0.0
set py_p 0.0
set Pval 0.0
set yval 0.01
while { $Pval < $cr_pl } {
   set Pval [expr $UP*$trib*0.9*$pu*tanh($kp*$cur_depth/0.9/$pu * $yval)]
   set yval [expr $yval+$incr]
}
set cr_di $yval

set kpy [expr $cr_pl/$cr_di/1000.0]
set epy [expr $Pmax/$kpy/1000.0]

set mn1 [expr $mat_num*2+1]
set mn2 [expr $mat_num*2+2]

# force-deformation relationships for p-y springs
#                              tag    K (k/in)   fy (k)      gap (in)
#uniaxialMaterial ElasticPP   $mat_num  $kpy  $epy
uniaxialMaterial ElasticPPGap  $mn1    $kpy  [expr -$kpy*$epy]   0
uniaxialMaterial ElasticPPGap  $mn2    $kpy  [expr  $kpy*$epy]   0
uniaxialMaterial Parallel    $mat_num $mn1 $mn2
}